@@ -1,7 +1,7 @@
 /* SASL server API implementation
  * Rob Siemborski
  * Tim Martin
- * $Id: checkpw.c,v 1.56 2002/05/22 16:20:28 leg Exp $
+ * $Id: checkpw.c,v 1.60 2002/10/02 15:50:09 ken3 Exp $
  */
 /* 
  * Copyright (c) 2001 Carnegie Mellon University.  All rights reserved.
@@ -69,7 +69,6 @@
 #include <strings.h>
 #include <netdb.h>
 #include <netinet/in.h>
-#include <sys/param.h>
 #include <sys/un.h>
 #else
 #include <string.h>
@@ -261,6 +260,7 @@ int _sasl_auxprop_verify_apop(sasl_conn_t *conn,
        !auxprop_values[0].values ||
        !auxprop_values[0].values[0]) {
 	sasl_seterror(conn, 0, "could not find password");
+	ret = SASL_NOUSER;
 	goto done;
     }
     
@@ -417,10 +417,11 @@ static int pwcheck_verify_password(sasl_conn_t *conn,
  * Keep calling the read() system call with 'fd', 'buf', and 'nbyte'
  * until all the data is read in or an error occurs.
  */
-static int retry_read(int fd, void *buf, unsigned nbyte)
+static int retry_read(int fd, void *buf0, unsigned nbyte)
 {
     int n;
     int nread = 0;
+    char *buf = buf0;
 
     if (nbyte == 0) return 0;
 
@@ -518,7 +519,7 @@ static int saslauthd_verify_password(sasl_conn_t *conn,
 #ifdef USE_DOORS
     s = open(pwpath, O_RDONLY);
     if (s < 0) {
-	sasl_seterror(conn, 0, "cannot open door to saslauthd server: %m");
+	sasl_seterror(conn, 0, "cannot open door to saslauthd server: %m", errno);
 	return SASL_FAIL;
     }
 
@@ -545,7 +546,7 @@ static int saslauthd_verify_password(sasl_conn_t *conn,
 
     s = socket(AF_UNIX, SOCK_STREAM, 0);
     if (s == -1) {
-	sasl_seterror(conn, 0, "cannot create socket for saslauthd: %m");
+	sasl_seterror(conn, 0, "cannot create socket for saslauthd: %m", errno);
 	return SASL_FAIL;
     }
 
@@ -556,7 +557,7 @@ static int saslauthd_verify_password(sasl_conn_t *conn,
     {
 	int r = connect(s, (struct sockaddr *) &srvaddr, sizeof(srvaddr));
 	if (r == -1) {
-	    sasl_seterror(conn, 0, "cannot connect to saslauthd server: %m");
+	    sasl_seterror(conn, 0, "cannot connect to saslauthd server: %m", errno);
 	    return SASL_FAIL;
 	}
     }
