@@ -1,7 +1,7 @@
 /* Kerberos4 SASL plugin
  * Rob Siemborski
  * Tim Martin 
- * $Id: kerberos4.c,v 1.92 2002/11/01 16:06:38 rjs3 Exp $
+ * $Id: kerberos4.c,v 1.93 2003/02/03 17:09:10 rjs3 Exp $
  */
 /* 
  * Copyright (c) 2001 Carnegie Mellon University.  All rights reserved.
@@ -47,7 +47,15 @@
 #include <stdlib.h>
 #include <string.h>
 #include <krb.h>
-#include <des.h>
+
+#ifdef WITH_DES
+# ifdef WITH_SSL_DES
+#  include <openssl/des.h>
+# else
+#  include <des.h>
+# endif /* WITH_SSL_DES */
+#endif /* WITH_DES */
+
 #ifdef WIN32
 # include <winsock.h>
 #elif defined(macintosh)
@@ -107,7 +115,7 @@ extern int gethostname(char *, int);
 
 /*****************************  Common Section  *****************************/
 
-static const char plugin_id[] = "$Id: kerberos4.c,v 1.92 2002/11/01 16:06:38 rjs3 Exp $";
+static const char plugin_id[] = "$Id: kerberos4.c,v 1.93 2003/02/03 17:09:10 rjs3 Exp $";
 
 #ifndef KEYFILE
 #define KEYFILE "/etc/srvtab";
